@charset "UTF-8";
/*
 * Import some paths that dont exists that leads to raise error
 */

@import "vendor";

// Error case, Path that don't exists
@import "dont_exists";

// Error cases, First does not exists and Second path filename exist 
// but with another extension
@import "scss_filetest",
    "css_filetest.sass";

// Following are ok
@import "components/filename_test_1";

@import "components/../empty";
