@charset "UTF-8";
/*
 * Import some components from imported libraries
 */

// Component from library 2
@import "addons/some_addon";

// Import another main file
@import "main_basic";

// Component that import another component (_webfont_icons.scss)
@import "components/webfont";

// Import full library 1 stack
@import "library_1_fullstack.scss";
